@@ -1,7 +1,10 @@
 ###########################################################
 # BIFIE.data objects for designs with jackknife zones
 BIFIE.data.jack <- function( data , wgt=NULL , jktype="JK_TIMSS" , pv_vars = NULL ,
-	jkzone=NULL , jkrep=NULL  ,	jkfac=NULL , fayfac = 1 , ngr = 100 , seed = .Random.seed
+	jkzone=NULL , jkrep=NULL  ,	jkfac=NULL , fayfac = 1 , 
+	wgtrep = "W_FSTR" , pvpre = paste0("PV",1:5) , ngr = 100 , 
+	seed = .Random.seed ,
+	cdata=FALSE
 		){	
 	#*** list of multiply imputed datasets
 	if ( ( is.list(data) ) & ( ! is.data.frame(data) ) ){
@@ -24,6 +27,7 @@ BIFIE.data.jack <- function( data , wgt=NULL , jktype="JK_TIMSS" , pv_vars = NUL
 		fayfac <- ngr / ( ngr - 1 )
         jkfac <- 0	 						
 							}
+
 	
 	#**********************************************************	
 	#*** defaults for jackknife creation: random groups
@@ -51,6 +55,7 @@ BIFIE.data.jack <- function( data , wgt=NULL , jktype="JK_TIMSS" , pv_vars = NUL
 		fayfac <- ngr / ( ngr - 1 )
         jkfac <- 0	     
 				}
+								
 	#**********************************************************
 	#**** defaults for TIMSS	
 	if (jktype == "JK_TIMSS"){
@@ -59,34 +64,45 @@ BIFIE.data.jack <- function( data , wgt=NULL , jktype="JK_TIMSS" , pv_vars = NUL
 		  wgt <- "TOTWGT"
 		  jkfac <- 2
 				}
-				
+	#***********************************************************
+	#**** defaults for PISA
+	if (jktype == "RW_PISA"){
+	      jkrep <- NULL
+	      jkzone <- NULL
+		  wgt <- "W_FSTUWT"
+		  jkfac <- NULL
+		  repvars <- grep( wgtrep , colnames( data ) )
+		  RR <- length(repvars)
+		  # select variables with plausible values
+		  nc1 <- nchar( pvpre[1] )
+		  pv_vars <- which( substring( colnames(data) , 1 , nc1 ) == pvpre[1] )
+		  pv_vars <- gsub( pvpre[1] , "" , colnames(data)[ pv_vars ] )
+#		  cdata <- FALSE
+				}								
 	#******** generate replicate weights
-	RR <- max( data[,jkzone] )
-#	datarep <- matrix( NA , nrow=nrow(data) , ncol=RR )
-#	colnames(datarep) <- paste0("R",1:RR)
-	prblen <- 10
-	prbar <- BIFIE.progressbar( ops = RR , prblen = prblen )
-	cat("+++ Generate replicate weights\n")
-	cat(paste0("|" , paste0(rep("*",prblen), collapse="") , "|\n|")) ; flush.console()
-	
-	addname <- 10^( floor( log( RR+.5 , 10 ) )  + 1 )
-#	colnames(datarep) <-  paste0("w_fstr" , substring( paste0(addname +1:RR),2) )	
-#	for (rr in 1:RR){    # rr <- 1
-#		vv <- paste0("w_fstr" , substring( addname +rr,2) )
-#		datarep[ , rr ] <- round( ifelse( as.numeric(paste0(data[,jkzone])) == rr , 
-#							jkfac*data[,wgt] * data[,jkrep] , 1*data[,wgt] ) , 5 )
-#		colnames(datarep)[rr] <- vv
-#		if ( prbar[rr] == 1 ){ cat("-" ) ; flush.console() }
-#				}
-    data[ , jkzone ] <- match( data[ , jkzone ] , unique( data[ , jkzone] ) )
-
-
-	datarep <- .Call( "bifie_jack_timss" , wgt_= data[,wgt] , data[,jkzone]-1 , data[,jkrep] , RR , jkfac ,
-					prbar , PACKAGE="BIFIEsurvey" )
-
-	colnames(datarep) <- paste0("w_fstr" , substring( paste0(addname +1:RR),2) )	
-	
-	cat("|\n")
+	if ( jktype != "RW_PISA") {
+		RR <- max( data[,jkzone] )		
+		prblen <- 10
+		prbar <- BIFIE.progressbar( ops = RR , prblen = prblen )
+		cat("+++ Generate replicate weights\n")
+		cat(paste0("|" , paste0(rep("*",prblen), collapse="") , "|\n|")) ; flush.console()	
+		addname <- 10^( floor( log( RR+.5 , 10 ) )  + 1 )
+		data[ , jkzone ] <- match( data[ , jkzone ] , unique( data[ , jkzone] ) )
+		datarep <- .Call( "bifie_jack_timss" , wgt_= data[,wgt] , data[,jkzone]-1 , data[,jkrep] , RR , jkfac ,
+						prbar , PACKAGE="BIFIEsurvey" )
+		colnames(datarep) <- paste0("w_fstr" , substring( paste0(addname +1:RR),2) )		
+		cat("|\n")
+					}
+	if ( jktype == "RW_PISA") {
+		datarep <- data[ , repvars ]
+        RR <- ncol(datarep)		
+		fayfac <- 1 /  RR / ( 1 - .5)^2
+#        if ( cdata ){
+         if (TRUE ){
+            data <- data[ , - repvars ]							
+					}
+		       }
+			   
 	#******** generate replicated datasets for datasets
 	if ( is.null( pv_vars) ){ datalist <- dataL  }
 	if ( ! is.null( pv_vars )){
@@ -94,14 +110,20 @@ BIFIE.data.jack <- function( data , wgt=NULL , jktype="JK_TIMSS" , pv_vars = NUL
 		VV <- length(pv_vars)
 		for (vv in 1:VV){
 			vv1 <- pv_vars[vv]
-			ind.vv1 <- which( substring( colnames(data) , 1 , nchar( vv1 ) ) == pv_vars[vv] )
+			if (jktype != "RW_PISA"){ 
+				ind.vv1 <- which( substring( colnames(data) , 1 , nchar( vv1 ) ) == pv_vars[vv] )
+									}  else {
+				varsel <- paste0( pvpre , vv1	)
+				ind.vv1 <- which( colnames(data) %in% varsel )									
+									}
+									
 			Nimp <- length(ind.vv1)
 			dfr2 <- data.frame( "variable" = vv1 , "var_index" = vv , "data_index" = ind.vv1 ,
-							 "impdata_index"=1:Nimp ) 			
+							 "impdata_index"=1:Nimp ) 				 
 			dfr <- rbind( dfr , dfr2 )
 			}
 		sel_ind <- setdiff( 1:( ncol(data) ) , dfr$data_index )
-		data0 <- data[ , sel_ind ]
+		data0 <- data[ , sel_ind ]	
 		V0 <- ncol(data0)
 		newvars <- seq( V0+1 , V0+VV )
 		datalist <- as.list( 1:Nimp )
@@ -109,10 +131,11 @@ BIFIE.data.jack <- function( data , wgt=NULL , jktype="JK_TIMSS" , pv_vars = NUL
 			dat1 <- data.frame( data0 , data[ , dfr[ dfr$impdata_index == ii  , "data_index" ] ] )
 			colnames(dat1)[ newvars ] <- pv_vars
 			datalist[[ii]] <- dat1 
-						}
-					}			
+						}  # end imputations						
+					}  # end pv_vars			
 	#*** create BIFIE.data object
-	bifiedat <- BIFIE.data( datalist , wgt = data[, wgt ] , wgtrep = datarep , fayfac = fayfac )
+	bifiedat <- BIFIE.data( datalist , wgt = data[, wgt ] , wgtrep = datarep , fayfac = fayfac ,
+	                   cdata=cdata)
 	return(bifiedat)
 }
 ###############################################################################
\ No newline at end of file
