@@ -8,6 +8,16 @@ BIFIE.linreg <- function( BIFIEobj , dep=NULL , pre=NULL  ,
 	#****
 	s1 <- Sys.time()
 	bifieobj <- BIFIEobj
+
+	if (bifieobj$cdata){
+	    fomula_vars <- NULL
+		if (! is.null(formula) ){
+			formula_vars <- all.vars( formula )
+							}
+		varnames <- unique( c( dep , pre , group , "one" , formula_vars ) )
+		bifieobj <- BIFIE.BIFIEcdata2BIFIEdata( bifieobj , varnames=varnames )	
+						}				
+			
 	FF <- Nimp <- bifieobj$Nimp
 	N <- bifieobj$N
 	dat1 <- bifieobj$dat1
@@ -26,6 +36,12 @@ BIFIE.linreg <- function( BIFIEobj , dep=NULL , pre=NULL  ,
 		if ( is.null(group) ){ group <- "one" ; group_values <- 1 }
 		bifieobj2 <- as.data.frame( bifieobj2 )
 	    m1 <- model.matrix(formula , data=bifieobj2)
+		#***
+        m0 <- m1
+		m1 <- matrix( NA , nrow=nrow(bifieobj2) , ncol=ncol(m0) )
+		m1[ match( rownames(m0),rownames(bifieobj2) ) , ] <- m0
+		colnames(m1) <- colnames(m0)
+		#****				
 		dep <- rownames( attr( terms(formula) ,"factors") )[1]
 		pre <- colnames( m1 )
 		datalistM <- as.matrix( cbind( bifieobj2[ , dep  ] , m1 , bifieobj2[,group] ) )
@@ -85,8 +101,8 @@ BIFIE.linreg <- function( BIFIEobj , dep=NULL , pre=NULL  ,
 	dfr$fmi <- res$regrcoefL$pars_fmi
 	dfr$VarMI <- res$regrcoefL$pars_varBetween
 	dfr$VarRep <- res$regrcoefL$pars_varWithin
-	if (RR==0){				
-		dfr$SE <- dfr$fmi <- dfr$VarMI <- dfr$VarRep <- NULL
+	if ( ( ! se ) &  ( RR==0 ) ){				
+		dfr$t <- dfr$p <- dfr$SE <- dfr$fmi <- dfr$VarMI <- dfr$VarRep <- NULL
 				}				
 
 	# create vector of parameter names
